#ifndef STORYBOOK_H
#define STORYBOOK_H

#include <vector>
#include <unordered_map>
#include <string>
#include <cstdio>
#include "cyoa.h"

class Storybook {
private:
  std::vector<Page*> pages;
  std::unordered_map<std::string, int> stats;
  Page *current;

  void print_choice(Choice *c);
public:
  Storybook(FILE* fin);
  
  // Functions for looking up and printing stats
  void UpdateStat(const char*, int);
  int LookupStat(const char*);
  std::vector<std::string> GetDefinedStats();

  // Functions to change the game state
  void Find(const char*);
  void Advance(); // For Goto and End cases
  void Advance(int); // For Choices
  bool IsChoiceAvailable(int);
  bool IsEnded = false;

  // This will probably be moved to the cli driver
  void Play();

  class IllegalChoiceException : std::exception {
    virtual const char *what() const noexcept {
      return "Illegal Choice.";
    }
  };
};

#endif /* STORYBOOK_H */
